==> ui-framework-elements-4.5.7.jar: gen/displays/templates/PropertyMold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import PropertyMoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import PropertyMoldRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class PropertyMold extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new PropertyMoldNotifier(this);
		this.requester = new PropertyMoldRequester(this);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock format="airBottom" layout="vertical" style={{...this.props.style,...display}}>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a187503373" format="body2 facetsAbsolute" mode="uppercase" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a982979818" layout="horizontal startjustified">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1611964513" format="h6" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a90975268" format="h6" mode="normal" value=":&nbsp;&nbsp;">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1612166416" format="h6 widgetType" mode="lowercase">
					</UiText>
				</UiBlock>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a312111403" format="body2" mode="normal" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a404081216" layout="horizontal">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a863348641" format="body2 valuesLabelFormat" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a919661842" format="body2 widgetType" mode="normal" value=":&nbsp;&nbsp;">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2138842349" format="body2" mode="normal">
					</UiText>
				</UiBlock>
			</UiBlock>
		);
	}


}

export default withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold));
DisplayFactory.register("PropertyMold", withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold)));

==> ui-framework-elements-4.11.1.jar: gen/displays/templates/PropertyMold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import PropertyMoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import PropertyMoldRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class PropertyMold extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new PropertyMoldNotifier(this);
		this.requester = new PropertyMoldRequester(this);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock format="airBottom" layout="vertical" style={{...this.props.style,...display}}>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a187503373" format="body2 facetsAbsolute" mode="uppercase" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_585219650" layout="horizontal startjustified">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_585219650.a_6728739" format="h6" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_585219650.a_931718105" format="h6" mode="normal" value=":&nbsp;&nbsp;">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_585219650.a_6526836" format="h6 widgetType" mode="lowercase">
					</UiText>
				</UiBlock>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a312111403" format="body2" mode="normal" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a429698665" layout="horizontal">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a429698665.a_102561798" format="body2 valuesLabelFormat" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a429698665.a1282701547" format="body2 widgetType" mode="normal" value=":&nbsp;&nbsp;">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a429698665.a1538254618" format="body2" mode="normal">
					</UiText>
				</UiBlock>
			</UiBlock>
		);
	}


}

export default withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold));
DisplayFactory.register("PropertyMold", withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold)));
